@@ -606,7 +606,29 @@ oneStep.setar <- function(object, newdata, itime, thVar, ...){
   (xL %*% phi1) * z + (xH %*% phi2) * (1-z)
 }
 
-toLatex.setar <- function(object, digits=3, ...) {
+
+
+#' Latex representation of fitted setar models
+#'
+#' Produce LaTeX output of the SETAR model. 
+#'
+#'
+#' @param object fitted setar model (using \code{\link{nlar}})
+#' @param digits options to be passed to \code{\link{format}} for formatting
+#' numbers
+#' @param label LaTeX label passed to the equation
+#' @param \dots Not used
+#' @author Antonio, Fabio Di Narzo
+#' @seealso \code{\link{setar}}, \code{\link{nlar-methods}}
+#' @keywords ts
+#' @examples
+#'
+#' mod.setar <- setar(log10(lynx), m=2, thDelay=1, th=3.25)
+#' toLatex(mod.setar)
+#'
+#' @method toLatex setar 
+#' @S3method toLatex setar 
+toLatex.setar <- function(object, digits=3, label, ...) {
   obj <- object
   mod<-obj$model.specific
   if(mod$nthresh > 1 & mod$common!="none")
@@ -623,7 +645,8 @@ toLatex.setar <- function(object, digits=3, ...) {
   th <- formatSignedNum(getTh(coefficients(obj)), digits=digits, ...)
   res[1] <- "\\["
   Xt<-if(type=="level") " X_{t-" else " \\Delta X_{t-"
-  res[2] <- paste(Xt,steps,"} = \\left\\{\\begin{array}{lr}",sep="")
+  lab <- if(missing(label)) NULL else label
+  res[2] <- paste(Xt,steps,"} = \\left\\{\\begin{array}{lr}",lab,sep="")
   translateCoefs <- function(coefs, lags, type=c("level", "diff", "ADF")) {
     ans <- ""
     if(length(lags) == (length(coefs) - 1)) { #there is a constant term
